export = memize;
/**
 * Memize options object.
 *
 * @typedef MemizeOptions
 *
 * @property {number} [maxSize] Maximum size of the cache.
 */
/**
 * Internal cache entry.
 *
 * @typedef MemizeCacheNode
 *
 * @property {?MemizeCacheNode|undefined} [prev] Previous node.
 * @property {?MemizeCacheNode|undefined} [next] Next node.
 * @property {Array<*>}                   args   Function arguments for cache
 *                                               entry.
 * @property {*}                          val    Function result.
 */
/**
 * Properties of the enhanced function for controlling cache.
 *
 * @typedef MemizeMemoizedFunction
 *
 * @property {()=>void} clear Clear the cache.
 */
/**
 * Accepts a function to be memoized, and returns a new memoized function, with
 * optional options.
 *
 * @template {Function} F
 *
 * @param {F}             fn        Function to memoize.
 * @param {MemizeOptions} [options] Options object.
 *
 * @return {F & MemizeMemoizedFunction} Memoized function.
 */
declare function memize<F extends Function>(fn: F, options?: MemizeOptions | undefined): F & MemizeMemoizedFunction;
declare namespace memize {
    export { MemizeOptions, MemizeCacheNode, MemizeMemoizedFunction };
}
/**
 * Memize options object.
 */
type MemizeOptions = {
    /**
     * Maximum size of the cache.
     */
    maxSize?: number;
};
/**
 * Properties of the enhanced function for controlling cache.
 */
type MemizeMemoizedFunction = {
    /**
     * Clear the cache.
     */
    clear: () => void;
};
/**
 * Internal cache entry.
 */
type MemizeCacheNode = {
    /**
     * Previous node.
     */
    prev?: MemizeCacheNode | null | undefined;
    /**
     * Next node.
     */
    next?: MemizeCacheNode | null | undefined;
    /**
     * Function arguments for cache
     * entry.
     */
    args: any[];
    /**
     * Function result.
     */
    val: any;
};
